# Module google/&zwnj;imagenet/&zwnj;mobilenet_v1_025_160/&zwnj;quantops/&zwnj;feature_vector/1

**Module URL:** [https://tfhub.dev/google/imagenet/mobilenet_v1_025_160/quantops/feature_vector/1](https://tfhub.dev/google/imagenet/mobilenet_v1_025_160/quantops/feature_vector/1)

## Overview

MobileNet V1 is a family of neural network architectures for efficient
on-device image classification, originally published by

  * Andrew G. Howard, Menglong Zhu, Bo Chen, Dmitry Kalenichenko, Weijun Wang,
    Tobias Weyand, Marco Andreetto, Hartwig Adam:
    ["MobileNets: Efficient Convolutional Neural Networks for
    Mobile Vision Applications"](https://arxiv.org/abs/1704.04861), 2017.

Mobilenets come in various sizes controlled by a multiplier for the
depth (number of features) in the convolutional layers. They can also be
trained for various sizes of input images to control inference speed.
This TF-Hub module uses the TF-Slim implementation of
`mobilenet_v1_v1_025`, **instrumented for quantization**,
with a depth multiplier of 0.25 and an input size of
160x160 pixels.

The module contains a trained instance of the network, packaged to get
[feature vectors from images](../../../../../../common_signatures/images.md#feature-vector).
If you want the full model including the classification it was originally
trained for, use module
[`google/imagenet/mobilenet_v1_025_160/quantops/classification/1`](../classification/1.md)
instead.


## Quantization

This module is meant for use in models whose weights will be quantized to
`uint8` by [TensorFlow Lite](https://www.tensorflow.org/mobile/tflite/)
for deployment to mobile devices.

The trained weights of this module are shipped as `float32` numbers,
but its graph has been augmented by `tf.contrib.quantize` with extra ops
that simulate the effect of quantization already during training,
so that the model can adjust to it.

## Training

The checkpoint exported into this module was `mobilenet_v1_2018_02_22/mobilenet_v1_0.25_160_quant/mobilenet_v1_0.25_160_quant.ckpt` downloaded
from
[MobileNet pre-trained models](https://github.com/tensorflow/models/blob/master/research/slim/nets/mobilenet_v1.md).
Its weights were originally obtained by training on the ILSVRC-2012-CLS
dataset for image classification ("Imagenet"), with simulated quantization.

## Usage

This module implements the common signature for computing
[image feature vectors](../../../../../../common_signatures/images.md#feature-vector).
It can be used like

```python
module = hub.Module("https://tfhub.dev/google/imagenet/mobilenet_v1_025_160/quantops/feature_vector/1")
height, width = hub.get_expected_image_size(module)
images = ...  # A batch of images with shape [batch_size, height, width, 3].
features = module(images)  # Features with shape [batch_size, num_features].
```

...or using the signature name `image_feature_vector`. The output for each image
in the batch is a feature vector of size `num_features` = 256.

For this module, the size of the input image is fixed to
`height` x `width` = 160 x 160 pixels.
The input `images` are expected to have color values in the range [0,1],
following the
[common image input](../../../../../../common_signatures/images.md#input)
conventions.


## Fine-tuning

The current version of this module only provides an inference graph
and cannot be fine-tuned.
