# Module google/&zwnj;imagenet/&zwnj;mobilenet_v1_075_224/&zwnj;classification/1

**Module URL:** [https://tfhub.dev/google/imagenet/mobilenet_v1_075_224/classification/1](https://tfhub.dev/google/imagenet/mobilenet_v1_075_224/classification/1)

## Overview

MobileNet V1 is a family of neural network architectures for efficient
on-device  image classification, originally published by

  * Andrew G. Howard, Menglong Zhu, Bo Chen, Dmitry Kalenichenko, Weijun Wang,
    Tobias Weyand, Marco Andreetto, Hartwig Adam:
    ["MobileNets: Efficient Convolutional Neural Networks for
    Mobile Vision Applications"](https://arxiv.org/abs/1704.04861), 2017.

Mobilenets come in various sizes controlled by a multiplier for the
depth (number of features) in the convolutional layers. They can also be
trained for various sizes of input images to control inference speed.
This TF-Hub module uses the TF-Slim implementation of
`mobilenet_v1_075`
with a depth multiplier of 0.75 and an input size of
224x224 pixels.

The module contains a trained instance of the network, packaged to do the
[image classification](../../../../../common_signatures/images.md#classification)
that the network was trained on. If you merely want to transform images into
feature vectors, use module
[`google/imagenet/mobilenet_v1_075_224/feature_vector/1`](../feature_vector/1.md)
instead, and save the space occupied by the classification layer.


## Training

The checkpoint exported into this module was `mobilenet_v1_2018_02_22/mobilenet_v1_0.75_224/mobilenet_v1_0.75_224.ckpt` downloaded
from
[MobileNet pre-trained models](https://github.com/tensorflow/models/blob/master/research/slim/nets/mobilenet_v1.md).
Its weights were originally obtained by training on the ILSVRC-2012-CLS
dataset for image classification ("Imagenet").

## Usage

This module implements the common signature for 
[image classification](../../../../../common_signatures/images.md#classification).
It can be used like

```python
module = hub.Module("https://tfhub.dev/google/imagenet/mobilenet_v1_075_224/classification/1")
height, width = hub.get_expected_image_size(module)
images = ...  # A batch of images with shape [batch_size, height, width, 3].
logits = module(images)  # Logits with shape [batch_size, num_classes].
```

...or using the signature name `image_classification`. The indices into logits
are the `num_classes` = 1001 classes of the classification from
the original training (see above).

This module can also be used to compute [image feature
vectors](../../../../../common_signatures/images.md#feature-vector),
using the signature name `image_feature_vector`.

For this module, the size of the input image is fixed to
`height` x `width` = 224 x 224 pixels.
The input `images` are expected to have color values in the range [0,1],
following the
[common image input](../../../../../common_signatures/images.md#input)
conventions.


## Fine-tuning

In principle, consumers of this module can
[fine-tune](../../../../../fine_tuning.md) it.
However, fine-tuning through a large classification might be prone to overfit.

Fine-tuning requires importing the graph version with tag set `{"train"}`
in order to operate batch normalization in training mode.

