# Module google/&zwnj;imagenet/&zwnj;resnet_v1_152/&zwnj;feature_vector/1

**Module URL:** [https://tfhub.dev/google/imagenet/resnet_v1_152/feature_vector/1](https://tfhub.dev/google/imagenet/resnet_v1_152/feature_vector/1)

## Overview

ResNet (later renamed ResNet V1) is a family of network architectures for
image classification with a variable number of layers, originally
published by

  * Kaiming He, Xiangyu Zhang, Shaoqing Ren, Jian Sun: ["Deep Residual Learning
    for Image Recognition"](https://arxiv.org/abs/1512.03385), 2015.

This TF-Hub module uses the TF-Slim implementation of `resnet_v1_152`
with 152 layers.
The module contains a trained instance of the network, packaged to get
[feature vectors from images](../../../../../common_signatures/images.md#feature-vector).
If you want the full model including the classification it was originally
trained for, use module
[`google/imagenet/resnet_v1_152/classification/1`](../classification/1.md)
instead.


## Training

The weights for this module were obtained by training on the ILSVRC-2012-CLS
dataset for image classification ("Imagenet") with TF-Slim's "Inception-style"
preprocessing.


## Usage

This module implements the common signature for computing
[image feature vectors](../../../../../common_signatures/images.md#feature-vector).
It can be used like

```python
module = hub.Module("https://tfhub.dev/google/imagenet/resnet_v1_152/feature_vector/1")
height, width = hub.get_expected_image_size(module)
images = ...  # A batch of images with shape [batch_size, height, width, 3].
features = module(images)  # Features with shape [batch_size, num_features].
```

...or using the signature name `image_feature_vector`. The output for each image
in the batch is a feature vector of size `num_features` = 2048.

For this module, the size of the input image is fixed to
`height` x `width` = 224 x 224 pixels.
The input `images` are expected to have color values in the range [0,1],
following the
[common image input](../../../../../common_signatures/images.md#input)
conventions.


## Fine-tuning

Consumers of this module can [fine-tune](../../../../../fine_tuning.md) it.
This requires importing the graph version with tag set `{"train"}`
in order to operate batch normalization in training mode.

